OC.L10N.register(
    "core",
    {
    "Sunday" : "रविवार",
    "Monday" : "सोमवार",
    "Tuesday" : "मंगलवार",
    "Wednesday" : "बुधवार",
    "Thursday" : "बृहस्पतिवार",
    "Friday" : "शुक्रवार",
    "Saturday" : "शनिवार",
    "January" : "जनवरी",
    "February" : "फरवरी",
    "March" : "मार्च",
    "April" : "अप्रैल",
    "May" : "मई",
    "June" : "जून",
    "July" : "जुलाई",
    "August" : "अगस्त",
    "September" : "सितम्बर",
    "October" : "अक्टूबर",
    "November" : "नवंबर",
    "December" : "दिसम्बर",
    "Settings" : "सेटिंग्स",
    "Saving..." : "सहेज रहे हैं...",
    "Cancel" : "रद्द करें ",
    "Error" : "त्रुटि",
    "Password" : "पासवर्ड",
    "Save" : "सहेजें",
    "Sending ..." : "भेजा जा रहा है",
    "Email sent" : "ईमेल भेज दिया गया है ",
    "Share" : "साझा करें",
    "Warning" : "चेतावनी ",
    "Add" : "डाले",
    "Personal" : "यक्तिगत",
    "Users" : "उपयोगकर्ता",
    "Apps" : "Apps",
    "Help" : "सहयोग",
    "Create an <strong>admin account</strong>" : "व्यवस्थापक खाता बनाएँ",
    "Username" : "प्रयोक्ता का नाम",
    "Data folder" : "डाटा फोल्डर",
    "Configure the database" : "डेटाबेस कॉन्फ़िगर करें ",
    "Database user" : "डेटाबेस उपयोगकर्ता",
    "Database password" : "डेटाबेस पासवर्ड",
    "Database name" : "डेटाबेस का नाम",
    "Finish setup" : "सेटअप समाप्त करे",
    "Log out" : "लोग  आउट",
    "Use the following link to reset your password: {link}" : "आगे दिये गये लिंक का उपयोग पासवर्ड बदलने के लिये किजीये: {link}",
    "New password" : "नया पासवर्ड"
},
"nplurals=2; plural=(n != 1);");
